@@ -24,7 +24,7 @@ EPIX_STDERR=$SYSTEM_STDERR
 
 declare EPIX_NOTFOUND
 
-declare EPIX_VERBOSE
+declare LATEX_PKGS
 
 # in increasing order of severity
 function ePiX_msg {
@@ -131,49 +131,49 @@ function epix_parse_filename {
 } # end of epix_parse_filename
 
 
+# Get extra LaTeX package names from file
+function ePiX_usepackages()
+{
+    TMP_PKGS=$(grep "%% usepackages " $1)
+    LATEX_PKGS=${TMP_PKGS#"%% usepackages "}
+}
+
 function ePiX_usage()
 {
 cat <<HELP
-Usage: $PROG [options] <file(s)>[$1]
+Usage: $1 [options] <file(s)>[$2]
 
 HELP
-} # End of ePiX_usage
+}
 
 
-function ePiX_version 
+function ePiX_version()
+{
+cat <<VERSION
+$1 (ePiX 1.2.4)
+
+Copyright (C) 2007  Andrew D. Hwang
+
+VERSION
+}
+
+function ePiX_license()
+{
+cat <<LICENSE
+License GPLv2+: GNU GPL version 2 or later <http://gnu.org/licenses/gpl.html>
+ePiX is free software: you are free to change and redistribute it.
+There is NO WARRANTY, to the extent permitted by law.
+
+LICENSE
+}
+
+function ePiX_bugreport()
 {
     my_decode="tr '[a-m][n-z]' '[n-z][a-m]'" # Mac OS X has no 'rot'
     SPAMMY="<$(echo nujnat|$my_decode)@$(echo zngupf|$my_decode)."
     SPAMMY="${SPAMMY}$(echo ubylpebff|$my_decode).$(echo rqh|$my_decode)>"
 
-cat <<VERSION
-$PROG is part of ePiX, Version 1.0.24
-
-Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006
-Andrew D. Hwang  $SPAMMY
-Department of Mathematics and Computer Science
-College of the Holy Cross
-Worcester, MA, 01610-2395, USA
-
-VERSION
-} # end of ePiX_version
-
-function ePiX_license
-{
-cat <<LICENSE
-  ePiX is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
- 
-  ePiX is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
-  or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public
-  License for more details.
- 
-  You should have received a copy of the GNU General Public License
-  along with ePiX; if not, write to the Free Software Foundation, Inc.,
-  59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
-
-LICENSE
-} # End of ePiX_version
+cat <<BUG
+Please report bugs to $SPAMMY
+BUG
+}
\ No newline at end of file
