@@ -1,15 +1,15 @@
 /* 
- *  triples.cc -- ePiX::P class
+ * triples.cc -- ePiX::P class
  *
- * This file is part of ePiX, a preprocessor for creating high-quality 
- * line figures in LaTeX 
+ * This file is part of ePiX, a C++ library for creating high-quality 
+ * figures in LaTeX 
  *
- * Version 1.0.15
- * Last Change: October 09, 2006
+ * Version 1.1.9
+ * Last Change: August 01, 2007
  */
 
 /* 
- * Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006
+ * Copyright (C) 2001, 2002, 2003, 2004, 2005, 2006, 2007
  * Andrew D. Hwang <rot 13 nujnat at zngupf dot ubylpebff dot rqh>
  * Department of Mathematics and Computer Science
  * College of the Holy Cross
@@ -31,53 +31,70 @@
  * along with ePiX; if not, write to the Free Software Foundation, Inc.,
  * 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
  */
-#include "globals.h"
+
+#include <cmath>
+
+#include "constants.h"
 #include "errors.h"
 #include "triples.h"
 
 namespace ePiX {
 
   P::P(double arg1, double arg2, double arg3)
-    : m_X1(arg1), m_X2(arg2), m_X3(arg3) { }
+    : m_x1(arg1), m_x2(arg2), m_x3(arg3) { }
 
   double P::x1() const
   {
-    return m_X1;
+    return m_x1;
   }
+
   double P::x2() const
   {
-    return m_X2;
+    return m_x2;
   }
+
   double P::x3() const
   {
-    return m_X3;
+    return m_x3;
+  }
+
+  bool P::is_valid() const
+  {
+    using std::isnan;
+    using std::isinf;
+
+    return
+         !isinf(m_x3) && !isnan(m_x3)
+      && !isinf(m_x2) && !isnan(m_x2)
+      && !isinf(m_x1) && !isnan(m_x1)
+      && m_x1*m_x1 + m_x2*m_x2 + m_x3*m_x3 < EPIX_INFTY;
   }
 
   // increment operators
   P& P::operator += (const P& arg)
   {
-    m_X1 += arg.m_X1;
-    m_X2 += arg.m_X2;
-    m_X3 += arg.m_X3;
+    m_x1 += arg.m_x1;
+    m_x2 += arg.m_x2;
+    m_x3 += arg.m_x3;
 
     return *this;
   }
 
   P& P::operator -= (const P& arg)
   {
-    m_X1 -= arg.m_X1;
-    m_X2 -= arg.m_X2;
-    m_X3 -= arg.m_X3;  
+    m_x1 -= arg.m_x1;
+    m_x2 -= arg.m_x2;
+    m_x3 -= arg.m_x3;  
 
     return *this;
   }
 
   // scalar multipication
-  P& P::operator *= (const double c)
+  P& P::operator *= (double c)
   {
-    m_X1 *= c;
-    m_X2 *= c;
-    m_X3 *= c;
+    m_x1 *= c;
+    m_x2 *= c;
+    m_x3 *= c;
 
     return *this;
   }
@@ -87,9 +104,9 @@ namespace ePiX {
   {
     P temp(*this);
 	  
-    m_X1 = (temp.m_X2 * v.m_X3 - temp.m_X3 * v.m_X2);
-    m_X2 = (temp.m_X3 * v.m_X1 - temp.m_X1 * v.m_X3);
-    m_X3 = (temp.m_X1 * v.m_X2 - temp.m_X2 * v.m_X1);
+    m_x1 = (temp.m_x2 * v.m_x3 - temp.m_x3 * v.m_x2);
+    m_x2 = (temp.m_x3 * v.m_x1 - temp.m_x1 * v.m_x3);
+    m_x3 = (temp.m_x1 * v.m_x2 - temp.m_x2 * v.m_x1);
 
     return *this;
   }
@@ -97,9 +114,9 @@ namespace ePiX {
   // componentwise product
   P& P::operator &= (const P& v)
   {
-    m_X1 *= v.m_X1;
-    m_X2 *= v.m_X2;
-    m_X3 *= v.m_X3;
+    m_x1 *= v.m_x1;
+    m_x2 *= v.m_x2;
+    m_x3 *= v.m_x3;
 
     return *this;
   }
@@ -107,7 +124,7 @@ namespace ePiX {
   // orthogonalization: u %= v is the vector of the form u-k*v perp to v
   P& P::operator%= (const P& v)
   { 
-    double denom(v.m_X1*v.m_X1 + v.m_X2*v.m_X2 + v.m_X3*v.m_X3);
+    double denom(v.m_x1*v.m_x1 + v.m_x2*v.m_x2 + v.m_x3*v.m_x3);
     if (denom < EPIX_EPSILON)
       {
 	epix_warning("Orthogonalizing by zero vector, no action");
@@ -115,59 +132,48 @@ namespace ePiX {
       }
 
     // else c=(u|v)/(v|v)
-    double c((m_X1*v.m_X1 + m_X2*v.m_X2 + m_X3*v.m_X3)/denom);
+    double c((m_x1*v.m_x1 + m_x2*v.m_x2 + m_x3*v.m_x3)/denom);
 
-    m_X1 -= c*v.m_X1;
-    m_X2 -= c*v.m_X2;
-    m_X3 -= c*v.m_X3;
+    m_x1 -= c*v.m_x1;
+    m_x2 -= c*v.m_x2;
+    m_x3 -= c*v.m_x3;
 
     return *this;
   }
   // end of class functions
 
   // vector space operations
-  P operator- (const P& u) 
+  P operator- (P u) 
   { 
-    P temp(u);
-    return temp *= -1;
+    return u *= -1;
   }
 
-  P operator+ (const P& u, const P& v) 
+  P operator+ (P u, const P& v) 
   { 
-    P temp(u);
-    return temp += v;
+    return u += v;
   }
 
-  P operator- (const P& u, const P& v) 
+  P operator- (P u, const P& v) 
   { 
-    P temp(u);
-    return temp -= v;
+    return u -= v;
   }
 
   // scalar multiplication
-  P operator* (const double c, const P& v) 
+  P operator* (double c, P v) 
   { 
-    P temp(v);
-    return temp *= c;
-  }
-
-  P midpoint(const P& u, const P& v, const double t)
-  {
-    return u + t*(v-u);
+    return v *= c;
   }
 
   // cross product
-  P operator* (const P& u, const P& v) 
+  P operator* (P u, const P& v) 
   { 
-    P temp(u);
-    return temp *= v;
+    return u *= v;
   }
 
-  P J(const P& arg) 
+  P J(P arg) 
   {
-    // E_3 * arg
-    P temp(-arg);
-    return temp *= E_3; 
+    // E_3 * arg, but E_3 is const
+    return arg *= -E_3; 
   }
 
   // dot product
@@ -182,16 +188,14 @@ namespace ePiX {
   }
 
   // componentwise product (a,b,c)&(x,y,z)=(ax,by,cz)
-  P operator& (const P& u, const P& v) 
+  P operator& (P u, const P& v) 
   { 
-    P temp(u);
-    return temp &= v;
+    return u &= v;
   }
 
-  P operator% (const P& u, const P& v) 
+  P operator% (P u, const P& v) 
   { 
-    P temp(u);
-    return temp %= v;
+    return u %= v;
   }
 
   // (in)equality
